geowatch.cli.queue\_cli.prepare\_splits module
==============================================

.. automodule:: geowatch.cli.queue_cli.prepare_splits
   :members:
   :undoc-members:
   :show-inheritance:
